@@ -37,11 +37,15 @@ severity_overrides:
 
 exclude:
   - DP001
+
+exclude_ignores:
+  - DP002
 `
 	c := load(t, "config.yaml", content)
 
 	assert.Contains(t, c.SeverityOverrides, "AWS018")
 	assert.Contains(t, c.ExcludedChecks, "DP001")
+	assert.Contains(t, c.ExcludeIgnores, "DP002")
 }
 
 func TestExcludesElementsFromYML(t *testing.T) {
@@ -51,11 +55,15 @@ severity_overrides:
 
 exclude:
   - DP001
+
+exclude_ignores:
+  - DP002
 `
 	c := load(t, "config.yml", content)
 
 	assert.Contains(t, c.SeverityOverrides, "AWS018")
 	assert.Contains(t, c.ExcludedChecks, "DP001")
+	assert.Contains(t, c.ExcludeIgnores, "DP002")
 }
 
 func TestExcludesElementsFromJSON(t *testing.T) {
@@ -65,6 +73,9 @@ func TestExcludesElementsFromJSON(t *testing.T) {
   },
   "exclude": [
     "DP001"
+  ],
+  "exclude_ignores": [
+    "DP002"
   ]
 }
 `
@@ -72,6 +83,7 @@ func TestExcludesElementsFromJSON(t *testing.T) {
 
 	assert.Contains(t, c.SeverityOverrides, "AWS018")
 	assert.Contains(t, c.ExcludedChecks, "DP001")
+	assert.Contains(t, c.ExcludeIgnores, "DP002")
 }
 
 func TestWarningIsRewrittenAsMedium(t *testing.T) {
